#include<joyos.h>

#include "define.h"
#include "bumper.h"

/**
 * bumperPressed returns 1 if the bumper at a particular digital
 * port is pressed. Returns 0 otherwise.
 *
 * @requires the given digital port is a valid port
 * @effects returns 1 if the bumper at the given port is pressed.
 *			Otherwise, returns 0
 * @modifies none
 */
uint8_t bumperPressed(uint8_t digital_port){
	uint8_t pressed = digital_read(digital_port);
	if(pressed == 0 || pressed == 1){
		return pressed;
	}else{
		return 0;
	}
}

/**
 * wallLeftBumperPressed returns 1 if the left wall-following
 * bumper is pressed. Otherwise, returns 0
 *
 * @requires none
 * @effects returns 1 if the left wall-following bumper is pressed.
 *			Otherwise, returns 0
 * @modifies none
 */
uint8_t wallLeftBumperPressed(void){
	return bumperPressed(BUMPER_WALL_LEFT);
}

/**
 * wallRightBumperPressed returns 1 if the right wall-following
 * bumper is pressed. Otherwise, returns 0.
 *
 * @requires none
 * @effects returns 1 if the right wall-following bumper is pressed.
 *			Otherwise, returns 0
 * @modifies none
 */
uint8_t wallRightBumperPressed(void){
	return bumperPressed(BUMPER_WALL_RIGHT);
}

/**
 * frontBumperPressed returns 1 iff the bumper sensor in front of the
 * robot is pressed. Returns 0 otherwise.
 *
 * @requires none
 * @effects returns 1 iff the front bumper is pressed.
 * 			Otherwise, returns 0
 * @modifies none
 */ 
uint8_t frontBumperPressed(void){
	return bumperPressed(BUMPER_FRONT);
}

uint8_t backLeftBumperPressed(void){
	return bumperPressed(BUMPER_BACK_LEFT);
}

uint8_t backRightBumperPressed(void){
	return bumperPressed(BUMPER_BACK_RIGHT);
}